You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jspwiki.apache.org by ja...@apache.org on 2009/02/01 19:04:50 UTC

svn commit: r739802 [5/13] - in /incubator/jspwiki/trunk: ./ doc/ etc/ etc/i18n/ etc/ini/ src/WebContent/ src/WebContent/WEB-INF/ src/WebContent/admin/ src/WebContent/scripts/ src/WebContent/templates/default/ src/WebContent/templates/default/admin/ sr...

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/api/WikiSession.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/api/WikiSession.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/Attachment.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/Attachment.java Sun Feb  1 18:04:05 2009
@@ -18,10 +18,10 @@
     specific language governing permissions and limitations
     under the License.     
  */
-package com.ecyrd.jspwiki.attachment;
+package org.apache.wiki.attachment;
 
-import com.ecyrd.jspwiki.JCRWikiPage;
-import com.ecyrd.jspwiki.WikiEngine;
+import org.apache.wiki.JCRWikiPage;
+import org.apache.wiki.WikiEngine;
 
 /**
  *  Describes an attachment.  Attachments are actually derivatives of

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentManager.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentManager.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.attachment;
+package org.apache.wiki.attachment;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -27,18 +27,18 @@
 import java.util.*;
 
 import org.apache.commons.lang.StringUtils;
-import org.apache.jspwiki.api.WikiException;
-import org.apache.jspwiki.api.WikiPage;
+import org.apache.wiki.*;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.api.WikiPage;
+import org.apache.wiki.content.WikiName;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.parser.MarkupParser;
+import org.apache.wiki.providers.ProviderException;
+import org.apache.wiki.providers.WikiAttachmentProvider;
+import org.apache.wiki.util.ClassUtil;
+
 
-import com.ecyrd.jspwiki.content.WikiName;
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
-
-import com.ecyrd.jspwiki.*;
-import com.ecyrd.jspwiki.parser.MarkupParser;
-import com.ecyrd.jspwiki.providers.ProviderException;
-import com.ecyrd.jspwiki.providers.WikiAttachmentProvider;
-import com.ecyrd.jspwiki.util.ClassUtil;
 import com.opensymphony.oscache.base.Cache;
 import com.opensymphony.oscache.base.NeedsRefreshException;
 
@@ -106,7 +106,7 @@
 
         if( useCache )
         {
-            classname = "com.ecyrd.jspwiki.providers.CachingAttachmentProvider";
+            classname = "org.apache.wiki.providers.CachingAttachmentProvider";
         }
         else
         {
@@ -127,7 +127,7 @@
         //
         try
         {
-            Class<?> providerclass = ClassUtil.findClass( "com.ecyrd.jspwiki.providers",
+            Class<?> providerclass = ClassUtil.findClass( "org.apache.wiki.providers",
                                                           classname );
 
             m_provider = (WikiAttachmentProvider)providerclass.newInstance();

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentServlet.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentServlet.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentServlet.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/AttachmentServlet.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.     
  */
-package com.ecyrd.jspwiki.attachment;
+package org.apache.wiki.attachment;
 
 import java.io.File;
 import java.io.IOException;
@@ -42,27 +42,27 @@
 import org.apache.commons.fileupload.ProgressListener;
 import org.apache.commons.fileupload.disk.DiskFileItemFactory;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
-import org.apache.jspwiki.api.WikiException;
-import org.apache.jspwiki.api.WikiPage;
+import org.apache.wiki.*;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.api.WikiPage;
+import org.apache.wiki.auth.AuthorizationManager;
+import org.apache.wiki.auth.permissions.PermissionFactory;
+import org.apache.wiki.dav.AttachmentDavProvider;
+import org.apache.wiki.dav.DavPath;
+import org.apache.wiki.dav.DavProvider;
+import org.apache.wiki.dav.WebdavServlet;
+import org.apache.wiki.dav.methods.DavMethod;
+import org.apache.wiki.dav.methods.PropFindMethod;
+import org.apache.wiki.filters.RedirectException;
+import org.apache.wiki.i18n.InternationalizationManager;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.providers.ProviderException;
+import org.apache.wiki.ui.progress.ProgressItem;
+import org.apache.wiki.util.HttpUtil;
+import org.apache.wiki.util.TextUtil;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.*;
-import com.ecyrd.jspwiki.auth.AuthorizationManager;
-import com.ecyrd.jspwiki.auth.permissions.PermissionFactory;
-import com.ecyrd.jspwiki.dav.AttachmentDavProvider;
-import com.ecyrd.jspwiki.dav.DavPath;
-import com.ecyrd.jspwiki.dav.DavProvider;
-import com.ecyrd.jspwiki.dav.WebdavServlet;
-import com.ecyrd.jspwiki.dav.methods.DavMethod;
-import com.ecyrd.jspwiki.dav.methods.PropFindMethod;
-import com.ecyrd.jspwiki.filters.RedirectException;
-import com.ecyrd.jspwiki.i18n.InternationalizationManager;
-import com.ecyrd.jspwiki.providers.ProviderException;
-import com.ecyrd.jspwiki.ui.progress.ProgressItem;
-import com.ecyrd.jspwiki.util.HttpUtil;
-import com.ecyrd.jspwiki.util.TextUtil;
 
 
 /**

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachment.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachment.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachment.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachment.java Sun Feb  1 18:04:05 2009
@@ -18,9 +18,9 @@
     specific language governing permissions and limitations
     under the License.     
  */
-package com.ecyrd.jspwiki.attachment;
+package org.apache.wiki.attachment;
 
-import com.ecyrd.jspwiki.WikiEngine;
+import org.apache.wiki.WikiEngine;
 
 /**
  *  A DynamicAttachment is an attachment which does not really exist, but is

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachmentProvider.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachmentProvider.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachmentProvider.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/DynamicAttachmentProvider.java Sun Feb  1 18:04:05 2009
@@ -18,13 +18,14 @@
     specific language governing permissions and limitations
     under the License.     
  */
-package com.ecyrd.jspwiki.attachment;
+package org.apache.wiki.attachment;
 
 import java.io.IOException;
 import java.io.InputStream;
 
-import com.ecyrd.jspwiki.WikiContext;
-import com.ecyrd.jspwiki.providers.ProviderException;
+import org.apache.wiki.WikiContext;
+import org.apache.wiki.providers.ProviderException;
+
 
 /**
  *  Provides the data for an attachment.  Please note that there will

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/package.html
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/package.html?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/package.html (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/package.html Sun Feb  1 18:04:05 2009
@@ -15,12 +15,12 @@
 <ul>
 <li>AttachmentServlet - the servlet which allows both uploading and downloading servlets.</li>
 <li>AttachmentManager - The JSPWiki Manager component which manages the storage of attachments.</li>
-<li>Attachment - A special kind of a {@link org.apache.jspwiki.api.WikiPage} which stores a handle
+<li>Attachment - A special kind of a {@link org.apache.wiki.api.WikiPage} which stores a handle
    to the attachment data.</li>
 </ul>
 
 <p>Attachments can either be static (i.e. real data, stored somewhere on a filesystem), or <i>dynamic</i>,
-which means that they're generated on the fly by a {@link com.ecyrd.jspwiki.attachment.DynamicAttachmentProvider}.</p>
+which means that they're generated on the fly by a {@link org.apache.wiki.attachment.DynamicAttachmentProvider}.</p>
 
 
 <h3>Related Documentation</h3>

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthenticationManager.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthenticationManager.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthenticationManager.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthenticationManager.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthenticationManager.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthenticationManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthenticationManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.io.File;
 import java.net.MalformedURLException;
@@ -33,21 +33,21 @@
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
 
-import org.apache.jspwiki.api.WikiException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.auth.authorize.Role;
+import org.apache.wiki.auth.authorize.WebContainerAuthorizer;
+import org.apache.wiki.auth.login.*;
+import org.apache.wiki.event.WikiEventListener;
+import org.apache.wiki.event.WikiEventManager;
+import org.apache.wiki.event.WikiSecurityEvent;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.util.TextUtil;
+import org.apache.wiki.util.TimedCounterList;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
-import com.ecyrd.jspwiki.auth.authorize.Role;
-import com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer;
-import com.ecyrd.jspwiki.auth.login.*;
-import com.ecyrd.jspwiki.event.WikiEventListener;
-import com.ecyrd.jspwiki.event.WikiEventManager;
-import com.ecyrd.jspwiki.event.WikiSecurityEvent;
-import com.ecyrd.jspwiki.util.TextUtil;
-import com.ecyrd.jspwiki.util.TimedCounterList;
 
 /**
  * Manages authentication activities for a WikiEngine: user login, logout, and
@@ -131,7 +131,7 @@
     protected static final String             SECURITY_CONTAINER = "container";
 
     /** The default {@link javax.security.auth.spi.LoginModule} class name to use for custom authentication. */
-    private static final String                 DEFAULT_LOGIN_MODULE = "com.ecyrd.jspwiki.auth.login.UserDatabaseLoginModule";
+    private static final String                 DEFAULT_LOGIN_MODULE = "org.apache.wiki.auth.login.UserDatabaseLoginModule";
     
     /** Empty principal set. */
     private static final Set<Principal> NO_PRINCIPALS = new HashSet<Principal>();
@@ -207,7 +207,7 @@
      * Returns true if this WikiEngine uses container-managed authentication.
      * This method is used primarily for cosmetic purposes in the JSP tier, and
      * performs no meaningful security function per se. Delegates to
-     * {@link com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer#isContainerAuthorized()},
+     * {@link org.apache.wiki.auth.authorize.WebContainerAuthorizer#isContainerAuthorized()},
      * if used as the external authorizer; otherwise, returns <code>false</code>.
      * @return <code>true</code> if the wiki's authentication is managed by
      *         the container, <code>false</code> otherwise
@@ -243,27 +243,27 @@
      * the request must supply one of the following (in order of preference):
      * the container <code>userPrincipal</code>, container <code>remoteUser</code>,
      * or authentication cookie. If the user is authenticated, this method fires event
-     * {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#LOGIN_AUTHENTICATED}
+     * {@link org.apache.wiki.event.WikiSecurityEvent#LOGIN_AUTHENTICATED}
      * with two parameters: a Principal representing the login principal,
      * and the current WikiSession. In addition, if the authorizer is of type
      * WebContainerAuthorizer, this method iterates through the container roles returned by
-     * {@link com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer#getRoles()},
+     * {@link org.apache.wiki.auth.authorize.WebContainerAuthorizer#getRoles()},
      * tests for membership in each one, and adds those that pass to the Subject's principal set.</li>
      * <li>If, after checking for authentication, the WikiSession is still Anonymous,
      * this method next checks to see if the user has "asserted" an identity
      * by supplying an assertion cookie. If the user is found to be asserted,
-     * this method fires event {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#LOGIN_ASSERTED}
+     * this method fires event {@link org.apache.wiki.event.WikiSecurityEvent#LOGIN_ASSERTED}
      * with two parameters: <code>WikiPrincipal(<em>cookievalue</em>)</code>, and
      * the current WikiSession.</li>
      * <li>If, after checking for authenticated and asserted status, the  WikiSession is
      * <em>still</em> anonymous, this method fires event
-     * {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#LOGIN_ANONYMOUS} with
+     * {@link org.apache.wiki.event.WikiSecurityEvent#LOGIN_ANONYMOUS} with
      * two parameters: <code>WikiPrincipal(<em>remoteAddress</em>)</code>,
      * and the current WikiSession </li>
      * </ul>
      * @param request servlet request for this user
      * @return always returns <code>true</code> (because anonymous login, at least, will always succeed)
-     * @throws com.ecyrd.jspwiki.auth.WikiSecurityException if the user cannot be logged in for any reason
+     * @throws org.apache.wiki.auth.WikiSecurityException if the user cannot be logged in for any reason
      * @since 2.3
      */
     public final boolean login( HttpServletRequest request ) throws WikiSecurityException
@@ -394,7 +394,7 @@
      * the JAAS LoginModule supplied by the WikiEngine property {@link #PROP_LOGIN_MODULE}
      * will be instantiated, and its
      * {@link javax.security.auth.spi.LoginModule#initialize(Subject, CallbackHandler, Map, Map)}
-     * method will be invoked. By default, the {@link com.ecyrd.jspwiki.auth.login.UserDatabaseLoginModule}
+     * method will be invoked. By default, the {@link org.apache.wiki.auth.login.UserDatabaseLoginModule}
      * class will be used. When the LoginModule's <code>initialize</code> method is invoked,
      * an options Map populated by properties keys prefixed by {@link #PREFIX_LOGIN_MODULE_OPTIONS}
      * will be passed as a parameter.
@@ -543,7 +543,7 @@
      * @param principal the principal to test
      * @return <code>true</code> if the Principal is of type
      *         {@link GroupPrincipal} or
-     *         {@link com.ecyrd.jspwiki.auth.authorize.Role},
+     *         {@link org.apache.wiki.auth.authorize.Role},
      *         <code>false</code> otherwise
      */
     public static final boolean isRolePrincipal( Principal principal )
@@ -556,7 +556,7 @@
      * @param principal the principal to test
      * @return <code>false</code> if the Principal is of type
      *         {@link GroupPrincipal} or
-     *         {@link com.ecyrd.jspwiki.auth.authorize.Role},
+     *         {@link org.apache.wiki.auth.authorize.Role},
      *         <code>true</code> otherwise
      */
     public static final boolean isUserPrincipal( Principal principal )
@@ -682,8 +682,8 @@
     }
 
     /**
-     * Returns the first Principal in a set that isn't a {@link com.ecyrd.jspwiki.auth.authorize.Role} or
-     * {@link com.ecyrd.jspwiki.auth.GroupPrincipal}.
+     * Returns the first Principal in a set that isn't a {@link org.apache.wiki.auth.authorize.Role} or
+     * {@link org.apache.wiki.auth.GroupPrincipal}.
      * @param principals the principal set
      * @return the login principal
      */
@@ -725,7 +725,7 @@
      *  Fires a WikiSecurityEvent of the provided type, Principal and target Object
      *  to all registered listeners.
      *
-     * @see com.ecyrd.jspwiki.event.WikiSecurityEvent
+     * @see org.apache.wiki.event.WikiSecurityEvent
      * @param type       the event type to be fired
      * @param principal  the subject of the event, which may be <code>null</code>
      * @param target     the changed Object, which may be <code>null</code>

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthorizationManager.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthorizationManager.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthorizationManager.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthorizationManager.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthorizationManager.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/AuthorizationManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/AuthorizationManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 
 import java.io.File;
@@ -29,29 +29,29 @@
 import java.util.Properties;
 import java.util.WeakHashMap;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import org.apache.jspwiki.api.WikiException;
-import org.apache.jspwiki.api.WikiPage;
+import org.apache.wiki.NoRequiredPropertyException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.api.WikiPage;
+import org.apache.wiki.auth.acl.Acl;
+import org.apache.wiki.auth.acl.AclEntry;
+import org.apache.wiki.auth.acl.UnresolvedPrincipal;
+import org.apache.wiki.auth.authorize.Role;
+import org.apache.wiki.auth.permissions.AllPermission;
+import org.apache.wiki.auth.permissions.PagePermission;
+import org.apache.wiki.auth.user.UserDatabase;
+import org.apache.wiki.auth.user.UserProfile;
+import org.apache.wiki.event.WikiEventListener;
+import org.apache.wiki.event.WikiEventManager;
+import org.apache.wiki.event.WikiSecurityEvent;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.util.ClassUtil;
 import org.freshcookies.security.policy.LocalPolicy;
 import org.freshcookies.security.policy.PolicyException;
 
-import com.ecyrd.jspwiki.NoRequiredPropertyException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
-import com.ecyrd.jspwiki.auth.acl.Acl;
-import com.ecyrd.jspwiki.auth.acl.AclEntry;
-import com.ecyrd.jspwiki.auth.acl.UnresolvedPrincipal;
-import com.ecyrd.jspwiki.auth.authorize.Role;
-import com.ecyrd.jspwiki.auth.permissions.AllPermission;
-import com.ecyrd.jspwiki.auth.permissions.PagePermission;
-import com.ecyrd.jspwiki.auth.user.UserDatabase;
-import com.ecyrd.jspwiki.auth.user.UserProfile;
-import com.ecyrd.jspwiki.event.WikiEventListener;
-import com.ecyrd.jspwiki.event.WikiEventManager;
-import com.ecyrd.jspwiki.event.WikiSecurityEvent;
-import com.ecyrd.jspwiki.util.ClassUtil;
 
 /**
  * <p>Manages all access control and authorization; determines what authenticated
@@ -59,14 +59,14 @@
  * <p>Privileges in JSPWiki are expressed as Java-standard {@link java.security.Permission}
  * classes. There are two types of permissions:</p>
  * <ul>
- *   <li>{@link com.ecyrd.jspwiki.auth.permissions.WikiPermission} - privileges that apply
+ *   <li>{@link org.apache.wiki.auth.permissions.WikiPermission} - privileges that apply
  *   to an entire wiki instance: <em>e.g.,</em> editing user profiles, creating pages, creating groups</li>
- *   <li>{@link com.ecyrd.jspwiki.auth.permissions.PagePermission} - privileges that apply
+ *   <li>{@link org.apache.wiki.auth.permissions.PagePermission} - privileges that apply
  *   to a single wiki page or range of pages: <em>e.g.,</em> reading, editing, renaming
  * </ul>
  * <p>Calling classes determine whether they are entitled to perform a particular action
  * by constructing the appropriate permission first, then passing it and the current
- * {@link com.ecyrd.jspwiki.WikiSession} to the
+ * {@link org.apache.wiki.WikiSession} to the
  * {@link #checkPermission(WikiSession, Permission)} method. If the session's
  * Subject possesses the permission, the action is allowed.</p>
  * <p>For WikiPermissions, the decision criteria is relatively simple: the caller either
@@ -90,9 +90,9 @@
 {
     private static final Logger log = LoggerFactory.getLogger( AuthorizationManager.class );
     /**
-     * The default external Authorizer is the {@link com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer}
+     * The default external Authorizer is the {@link org.apache.wiki.auth.authorize.WebContainerAuthorizer}
      */
-    public static final String                DEFAULT_AUTHORIZER = "com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer";
+    public static final String                DEFAULT_AUTHORIZER = "org.apache.wiki.auth.authorize.WebContainerAuthorizer";
 
     /** Property that supplies the security policy file name, in WEB-INF. */
     protected static final String             POLICY      = "jspwiki.policy.file";
@@ -128,9 +128,9 @@
      * whether a Permission is allowed for the Subject associated with
      * a supplied WikiSession. The access control algorithm works this way:
      * <ol>
-     * <li>The {@link com.ecyrd.jspwiki.auth.acl.Acl} for the page is obtained</li>
+     * <li>The {@link org.apache.wiki.auth.acl.Acl} for the page is obtained</li>
      * <li>The Subject associated with the current
-     * {@link com.ecyrd.jspwiki.WikiSession} is obtained</li>
+     * {@link org.apache.wiki.WikiSession} is obtained</li>
      * <li>If the Subject's Principal set includes the Role Principal that is
      * the administrator group, always allow the Permission</li>
      * <li>For all permissions, check to see if the Permission is allowed according
@@ -138,7 +138,7 @@
      * further processing.</li>
      * <li>If there is an Acl, get the list of Principals assigned this
      * Permission in the Acl: these will be role, group or user Principals, or
-     * {@link com.ecyrd.jspwiki.auth.acl.UnresolvedPrincipal}s (see below).
+     * {@link org.apache.wiki.auth.acl.UnresolvedPrincipal}s (see below).
      * Then iterate through the Subject's Principal set and determine whether
      * the user (Subject) posesses any one of these specified Roles or
      * Principals. The matching process delegates to
@@ -312,8 +312,8 @@
      * Returns the current external {@link Authorizer} in use. This method
      * is guaranteed to return a properly-initialized Authorizer, unless
      * it could not be initialized. In that case, this method throws
-     * a {@link com.ecyrd.jspwiki.auth.WikiSecurityException}.
-     * @throws com.ecyrd.jspwiki.auth.WikiSecurityException if the Authorizer could
+     * a {@link org.apache.wiki.auth.WikiSecurityException}.
+     * @throws org.apache.wiki.auth.WikiSecurityException if the Authorizer could
      * not be initialized
      * @return the current Authorizer
      */
@@ -468,7 +468,7 @@
         {
             try
             {
-                Class<?> authClass = ClassUtil.findClass( "com.ecyrd.jspwiki.auth.authorize", clazz );
+                Class<?> authClass = ClassUtil.findClass( "org.apache.wiki.auth.authorize", clazz );
                 Object impl = authClass.newInstance();
                 return impl;
             }
@@ -579,18 +579,18 @@
      * This method is guaranteed to always return a Principal.
      * The algorithm is straightforward:</p>
      * <ol>
-     * <li>If the name matches one of the built-in {@link com.ecyrd.jspwiki.auth.authorize.Role} names,
+     * <li>If the name matches one of the built-in {@link org.apache.wiki.auth.authorize.Role} names,
      * return that built-in Role</li>
      * <li>If the name matches one supplied by the current
-     * {@link com.ecyrd.jspwiki.auth.Authorizer}, return that Role</li>
+     * {@link org.apache.wiki.auth.Authorizer}, return that Role</li>
      * <li>If the name matches a group managed by the
-     * current {@link com.ecyrd.jspwiki.auth.authorize.GroupManager}, return that Group</li>
+     * current {@link org.apache.wiki.auth.authorize.GroupManager}, return that Group</li>
      * <li>Otherwise, assume that the name represents a user
-     * principal. Using the current {@link com.ecyrd.jspwiki.auth.user.UserDatabase}, find the
+     * principal. Using the current {@link org.apache.wiki.auth.user.UserDatabase}, find the
      * first user who matches the supplied name by calling
-     * {@link com.ecyrd.jspwiki.auth.user.UserDatabase#find(String)}.</li>
+     * {@link org.apache.wiki.auth.user.UserDatabase#find(String)}.</li>
      * <li>Finally, if a user cannot be found, manufacture
-     * and return a generic {@link com.ecyrd.jspwiki.auth.acl.UnresolvedPrincipal}</li>
+     * and return a generic {@link org.apache.wiki.auth.acl.UnresolvedPrincipal}</li>
      * </ol>
      * @param name the name of the Principal to resolve
      * @return the fully-resolved Principal
@@ -673,7 +673,7 @@
      *  Fires a WikiSecurityEvent of the provided type, user,
      *  and permission to all registered listeners.
      *
-     * @see com.ecyrd.jspwiki.event.WikiSecurityEvent
+     * @see org.apache.wiki.event.WikiSecurityEvent
      * @param type        the event type to be fired
      * @param user        the user associated with the event
      * @param permission  the permission the subject must possess

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/Authorizer.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/Authorizer.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/Authorizer.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/Authorizer.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/Authorizer.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/Authorizer.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/Authorizer.java Sun Feb  1 18:04:05 2009
@@ -18,13 +18,14 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.security.Principal;
 import java.util.Properties;
 
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+
 
 /**
  * Interface for service providers of authorization information.

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/GroupPrincipal.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/GroupPrincipal.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/GroupPrincipal.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/GroupPrincipal.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/GroupPrincipal.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/GroupPrincipal.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/GroupPrincipal.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.security.Principal;
 
@@ -31,7 +31,7 @@
  * memberships can be changed by callers). Administrators who wish to grant
  * privileges to specific wiki groups via the security policy file should always specify
  * principals of type GroupPrincipal.
- * @see com.ecyrd.jspwiki.auth.authorize.Group
+ * @see org.apache.wiki.auth.authorize.Group
  * @author Andrew Jaquith
  * @since 2.3.79
  */

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/NoSuchPrincipalException.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/NoSuchPrincipalException.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/NoSuchPrincipalException.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/NoSuchPrincipalException.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/NoSuchPrincipalException.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/NoSuchPrincipalException.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/NoSuchPrincipalException.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 /**
  *  Thrown in some error situations where a WikiPrincipal object does not exist.

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/PrincipalComparator.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/PrincipalComparator.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/PrincipalComparator.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/PrincipalComparator.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/PrincipalComparator.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/PrincipalComparator.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/PrincipalComparator.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.io.Serializable;
 import java.security.Principal;

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SecurityVerifier.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SecurityVerifier.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SecurityVerifier.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SecurityVerifier.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SecurityVerifier.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SecurityVerifier.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SecurityVerifier.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.io.File;
 import java.io.IOException;
@@ -33,23 +33,23 @@
 import javax.security.auth.spi.LoginModule;
 
 import org.apache.commons.lang.ArrayUtils;
-import org.apache.jspwiki.api.WikiException;
+import org.apache.wiki.InternalWikiException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.auth.authorize.*;
+import org.apache.wiki.auth.permissions.AllPermission;
+import org.apache.wiki.auth.permissions.GroupPermission;
+import org.apache.wiki.auth.permissions.PermissionFactory;
+import org.apache.wiki.auth.permissions.WikiPermission;
+import org.apache.wiki.auth.user.UserDatabase;
+import org.apache.wiki.auth.user.UserProfile;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 import org.freshcookies.security.policy.PolicyReader;
 import org.jdom.JDOMException;
 
-import com.ecyrd.jspwiki.InternalWikiException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
-import com.ecyrd.jspwiki.auth.authorize.*;
-import com.ecyrd.jspwiki.auth.permissions.AllPermission;
-import com.ecyrd.jspwiki.auth.permissions.GroupPermission;
-import com.ecyrd.jspwiki.auth.permissions.PermissionFactory;
-import com.ecyrd.jspwiki.auth.permissions.WikiPermission;
-import com.ecyrd.jspwiki.auth.user.UserDatabase;
-import com.ecyrd.jspwiki.auth.user.UserProfile;
 
 /**
  * Helper class for verifying JSPWiki's security configuration. Invoked by
@@ -175,7 +175,7 @@
      * Formats and returns an HTML table containing sample permissions and what
      * roles are allowed to have them. This method will throw an
      * {@link IllegalStateException} if the authorizer is not of type
-     * {@link com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer}
+     * {@link org.apache.wiki.auth.authorize.WebContainerAuthorizer}
      * @return the formatted HTML table containing the result of the tests
      */
     public final String policyRoleTable()
@@ -343,7 +343,7 @@
      * Formats and returns an HTML table containing the roles the web container
      * is aware of, and whether each role maps to particular JSPs. This method
      * throws an {@link IllegalStateException} if the authorizer is not of type
-     * {@link com.ecyrd.jspwiki.auth.authorize.WebContainerAuthorizer}
+     * {@link org.apache.wiki.auth.authorize.WebContainerAuthorizer}
      * @return the formatted HTML table containing the result of the tests
      * @throws WikiException if tests fail for unexpected reasons
      */
@@ -588,7 +588,7 @@
     /**
      * Verfies the JAAS configuration. The configuration is valid if value of the
      * <code>jspwiki.properties<code> property
-     * {@value com.ecyrd.jspwiki.auth.AuthenticationManager#PROP_LOGIN_MODULE}
+     * {@value org.apache.wiki.auth.AuthenticationManager#PROP_LOGIN_MODULE}
      * resolves to a valid class on the classpath.
      */
     protected final void verifyJaas()

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SessionMonitor.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SessionMonitor.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SessionMonitor.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SessionMonitor.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SessionMonitor.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/SessionMonitor.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/SessionMonitor.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.security.Principal;
 import java.util.*;
@@ -29,15 +29,16 @@
 import javax.servlet.http.HttpSessionEvent;
 import javax.servlet.http.HttpSessionListener;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.event.WikiEventListener;
+import org.apache.wiki.event.WikiEventManager;
+import org.apache.wiki.event.WikiSecurityEvent;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.rpc.json.JSONRPCManager;
+
 
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
-import com.ecyrd.jspwiki.event.WikiEventListener;
-import com.ecyrd.jspwiki.event.WikiEventManager;
-import com.ecyrd.jspwiki.event.WikiSecurityEvent;
-import com.ecyrd.jspwiki.rpc.json.JSONRPCManager;
 
 /**
  *  <p>Manages WikiSession's for different WikiEngine's.</p>
@@ -297,7 +298,7 @@
     /**
      * When the servlet context is destroyed, this method
      * obtains the associated WikiEngine and executes its
-     * {@link com.ecyrd.jspwiki.WikiEngine#shutdown()}
+     * {@link org.apache.wiki.WikiEngine#shutdown()}
      * method.
      * @param sce the servlet context event
      */

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/UserManager.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/UserManager.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/UserManager.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/UserManager.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/UserManager.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/UserManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/UserManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.io.Serializable;
 import java.security.Permission;
@@ -31,30 +31,30 @@
 import javax.security.auth.login.LoginException;
 import javax.servlet.http.HttpServletRequest;
 
-import org.apache.jspwiki.api.WikiException;
+import org.apache.wiki.*;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.auth.permissions.AllPermission;
+import org.apache.wiki.auth.permissions.WikiPermission;
+import org.apache.wiki.auth.user.AbstractUserDatabase;
+import org.apache.wiki.auth.user.DuplicateUserException;
+import org.apache.wiki.auth.user.UserDatabase;
+import org.apache.wiki.auth.user.UserProfile;
+import org.apache.wiki.event.WikiEventListener;
+import org.apache.wiki.event.WikiEventManager;
+import org.apache.wiki.event.WikiSecurityEvent;
+import org.apache.wiki.filters.PageFilter;
+import org.apache.wiki.filters.SpamFilter;
+import org.apache.wiki.i18n.InternationalizationManager;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.rpc.RPCCallable;
+import org.apache.wiki.rpc.json.JSONRPCManager;
+import org.apache.wiki.ui.InputValidator;
+import org.apache.wiki.util.ClassUtil;
+import org.apache.wiki.util.MailUtil;
+import org.apache.wiki.workflow.*;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.*;
-import com.ecyrd.jspwiki.auth.permissions.AllPermission;
-import com.ecyrd.jspwiki.auth.permissions.WikiPermission;
-import com.ecyrd.jspwiki.auth.user.AbstractUserDatabase;
-import com.ecyrd.jspwiki.auth.user.DuplicateUserException;
-import com.ecyrd.jspwiki.auth.user.UserDatabase;
-import com.ecyrd.jspwiki.auth.user.UserProfile;
-import com.ecyrd.jspwiki.event.WikiEventListener;
-import com.ecyrd.jspwiki.event.WikiEventManager;
-import com.ecyrd.jspwiki.event.WikiSecurityEvent;
-import com.ecyrd.jspwiki.filters.PageFilter;
-import com.ecyrd.jspwiki.filters.SpamFilter;
-import com.ecyrd.jspwiki.i18n.InternationalizationManager;
-import com.ecyrd.jspwiki.rpc.RPCCallable;
-import com.ecyrd.jspwiki.rpc.json.JSONRPCManager;
-import com.ecyrd.jspwiki.ui.InputValidator;
-import com.ecyrd.jspwiki.util.ClassUtil;
-import com.ecyrd.jspwiki.util.MailUtil;
-import com.ecyrd.jspwiki.workflow.*;
 
 /**
  * Provides a facade for obtaining user information.
@@ -63,7 +63,7 @@
  */
 public final class UserManager
 {
-    private static final String USERDATABASE_PACKAGE = "com.ecyrd.jspwiki.auth.user";
+    private static final String USERDATABASE_PACKAGE = "org.apache.wiki.auth.user";
     private static final String SESSION_MESSAGES = "profile";
     private static final String PARAM_EMAIL = "email";
     private static final String PARAM_FULLNAME = "fullname";
@@ -186,20 +186,20 @@
     }
 
     /**
-     * <p>Retrieves the {@link com.ecyrd.jspwiki.auth.user.UserProfile}for the
+     * <p>Retrieves the {@link org.apache.wiki.auth.user.UserProfile}for the
      * user in a wiki session. If the user is authenticated, the UserProfile
      * returned will be the one stored in the user database; if one does not
      * exist, a new one will be initialized and returned. If the user is
      * anonymous or asserted, the UserProfile will <i>always</i> be newly
      * initialized to prevent spoofing of identities. If a UserProfile needs to
      * be initialized, its
-     * {@link com.ecyrd.jspwiki.auth.user.UserProfile#isNew()} method will
+     * {@link org.apache.wiki.auth.user.UserProfile#isNew()} method will
      * return <code>true</code>, and its login name will will be set
      * automatically if the user is authenticated. Note that this method does
      * not modify the retrieved (or newly created) profile otherwise; other
      * fields in the user profile may be <code>null</code>.</p>
      * <p>If a new UserProfile was created, but its
-     * {@link com.ecyrd.jspwiki.auth.user.UserProfile#isNew()} method returns
+     * {@link org.apache.wiki.auth.user.UserProfile#isNew()} method returns
      * <code>false</code>, this method throws an {@link IllegalStateException}.
      * This is meant as a quality check for UserDatabase providers;
      * it should only be thrown if the implementation is faulty.</p>
@@ -250,7 +250,7 @@
 
     /**
      * <p>
-     * Saves the {@link com.ecyrd.jspwiki.auth.user.UserProfile}for the user in
+     * Saves the {@link org.apache.wiki.auth.user.UserProfile}for the user in
      * a wiki session. This method verifies that a user profile to be saved
      * doesn't collide with existing profiles; that is, the login name
      * or full name is already used by another profile. If the profile
@@ -279,9 +279,9 @@
      * @param profile the user profile, which may not be <code>null</code>
      * @throws DuplicateUserException if the proposed profile's login name or full name collides with another
      * @throws WikiException if the save fails for some reason. If the current user does not have
-     * permission to save the profile, this will be a {@link com.ecyrd.jspwiki.auth.WikiSecurityException};
+     * permission to save the profile, this will be a {@link org.apache.wiki.auth.WikiSecurityException};
      * if if the user profile must be approved before it can be saved, it will be a
-     * {@link com.ecyrd.jspwiki.workflow.DecisionRequiredException}. All other WikiException
+     * {@link org.apache.wiki.workflow.DecisionRequiredException}. All other WikiException
      * indicate a condition that is not normal is probably due to mis-configuration
      */
     public final void setUserProfile( WikiSession session, UserProfile profile ) throws DuplicateUserException, WikiException
@@ -425,7 +425,7 @@
      * always override whatever values the user supplied.</li> <li>If
      * container authentication is used, the login name property of the profile
      * is set to the name of
-     * {@link com.ecyrd.jspwiki.WikiSession#getLoginPrincipal()}. Otherwise,
+     * {@link org.apache.wiki.WikiSession#getLoginPrincipal()}. Otherwise,
      * the value of the <code>loginname</code> parameter is used.</li> </ul>
      * @param context the current wiki context
      * @return a new, populated user profile
@@ -710,7 +710,7 @@
     /**
      * Inner class that handles the actual profile save action. Instances
      * of this class are assumed to have been added to an approval workflow via
-     * {@link com.ecyrd.jspwiki.workflow.WorkflowBuilder#buildApprovalWorkflow(Principal, String, Task, String, com.ecyrd.jspwiki.workflow.Fact[], Task, String)};
+     * {@link org.apache.wiki.workflow.WorkflowBuilder#buildApprovalWorkflow(Principal, String, Task, String, org.apache.wiki.workflow.Fact[], Task, String)};
      * they will not function correctly otherwise.
      *
      * @author Andrew Jaquith
@@ -734,7 +734,7 @@
 
         /**
          * Saves the user profile to the user database.
-         * @return {@link com.ecyrd.jspwiki.workflow.Outcome#STEP_COMPLETE} if the
+         * @return {@link org.apache.wiki.workflow.Outcome#STEP_COMPLETE} if the
          * task completed successfully
          * @throws WikiException if the save did not complete for some reason
          */
@@ -802,7 +802,7 @@
      *  Fires a WikiSecurityEvent of the provided type, Principal and target Object
      *  to all registered listeners.
      *
-     * @see com.ecyrd.jspwiki.event.WikiSecurityEvent
+     * @see org.apache.wiki.event.WikiSecurityEvent
      * @param type       the event type to be fired
      * @param session    the wiki session supporting the event
      * @param profile    the user profile (or array of user profiles), which may be <code>null</code>

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiPrincipal.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiPrincipal.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiPrincipal.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiPrincipal.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiPrincipal.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiPrincipal.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiPrincipal.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
 import java.io.Serializable;
 import java.security.Principal;

Copied: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiSecurityException.java (from r739575, incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiSecurityException.java)
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiSecurityException.java?p2=incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiSecurityException.java&p1=incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiSecurityException.java&r1=739575&r2=739802&rev=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/com/ecyrd/jspwiki/auth/WikiSecurityException.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/WikiSecurityException.java Sun Feb  1 18:04:05 2009
@@ -18,9 +18,9 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth;
+package org.apache.wiki.auth;
 
-import org.apache.jspwiki.api.WikiException;
+import org.apache.wiki.api.WikiException;
 
 /**
  * Indicates an authentication or authorization error or exception.

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/Acl.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/Acl.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/Acl.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/Acl.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.security.Permission;
 import java.security.Principal;

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntry.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntry.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclImpl.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclImpl.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.io.Serializable;
 import java.security.Permission;

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclManager.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclManager.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclManager.java Sun Feb  1 18:04:05 2009
@@ -18,14 +18,14 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.util.Properties;
 
-import org.apache.jspwiki.api.WikiPage;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.api.WikiPage;
+import org.apache.wiki.auth.WikiSecurityException;
 
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.auth.WikiSecurityException;
 
 /**
  *  Specifies how to parse and return ACLs from wiki pages.

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/DefaultAclManager.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/DefaultAclManager.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/DefaultAclManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/DefaultAclManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.security.Permission;
 import java.security.Principal;
@@ -26,20 +26,20 @@
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import org.apache.jspwiki.api.WikiPage;
+import org.apache.wiki.*;
+import org.apache.wiki.api.WikiPage;
+import org.apache.wiki.attachment.Attachment;
+import org.apache.wiki.auth.AuthorizationManager;
+import org.apache.wiki.auth.PrincipalComparator;
+import org.apache.wiki.auth.WikiSecurityException;
+import org.apache.wiki.auth.permissions.PagePermission;
+import org.apache.wiki.auth.permissions.PermissionFactory;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.providers.ProviderException;
+import org.apache.wiki.render.RenderingManager;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.*;
-import com.ecyrd.jspwiki.attachment.Attachment;
-import com.ecyrd.jspwiki.auth.AuthorizationManager;
-import com.ecyrd.jspwiki.auth.PrincipalComparator;
-import com.ecyrd.jspwiki.auth.WikiSecurityException;
-import com.ecyrd.jspwiki.auth.permissions.PagePermission;
-import com.ecyrd.jspwiki.auth.permissions.PermissionFactory;
-import com.ecyrd.jspwiki.providers.ProviderException;
-import com.ecyrd.jspwiki.render.RenderingManager;
 
 /**
  * Default implementation that parses Acls from wiki page markup.
@@ -73,7 +73,7 @@
      * Initializes the AclManager with a supplied wiki engine and properties.
      * @param engine the wiki engine
      * @param props the initialization properties
-     * @see com.ecyrd.jspwiki.auth.acl.AclManager#initialize(com.ecyrd.jspwiki.WikiEngine,
+     * @see org.apache.wiki.auth.acl.AclManager#initialize(org.apache.wiki.WikiEngine,
      *      java.util.Properties)
      */
     public void initialize( WikiEngine engine, Properties props )

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/UnresolvedPrincipal.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/UnresolvedPrincipal.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/UnresolvedPrincipal.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/UnresolvedPrincipal.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.io.Serializable;
 import java.security.Principal;

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Group.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Group.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Group.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Group.java Sun Feb  1 18:04:05 2009
@@ -18,13 +18,14 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.security.Principal;
 import java.util.Date;
 import java.util.Vector;
 
-import com.ecyrd.jspwiki.auth.GroupPrincipal;
+import org.apache.wiki.auth.GroupPrincipal;
+
 
 /**
  * <p>
@@ -86,7 +87,7 @@
      * Protected constructor to prevent direct instantiation except by other
      * package members. Callers should use
      * {@link GroupManager#parseGroup(String, String, boolean)} or
-     * {@link GroupManager#parseGroup(com.ecyrd.jspwiki.WikiContext, boolean)}.
+     * {@link GroupManager#parseGroup(org.apache.wiki.WikiContext, boolean)}.
      * instead.
      * @param name the name of the group
      * @param wiki the wiki the group belongs to

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupDatabase.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupDatabase.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupDatabase.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupDatabase.java Sun Feb  1 18:04:05 2009
@@ -18,15 +18,16 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.security.Principal;
 import java.util.Properties;
 
-import com.ecyrd.jspwiki.NoRequiredPropertyException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.auth.NoSuchPrincipalException;
-import com.ecyrd.jspwiki.auth.WikiSecurityException;
+import org.apache.wiki.NoRequiredPropertyException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.auth.NoSuchPrincipalException;
+import org.apache.wiki.auth.WikiSecurityException;
+
 
 /**
  * Defines an interface for loading, persisting and storing wiki groups.

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupManager.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupManager.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupManager.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/GroupManager.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.security.Principal;
 import java.util.HashMap;
@@ -31,23 +31,23 @@
 import javax.servlet.http.HttpServletRequest;
 
 import org.apache.commons.lang.ArrayUtils;
-import org.apache.jspwiki.api.WikiException;
+import org.apache.wiki.NoRequiredPropertyException;
+import org.apache.wiki.WikiContext;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.api.WikiException;
+import org.apache.wiki.auth.*;
+import org.apache.wiki.auth.user.UserProfile;
+import org.apache.wiki.event.WikiEvent;
+import org.apache.wiki.event.WikiEventListener;
+import org.apache.wiki.event.WikiEventManager;
+import org.apache.wiki.event.WikiSecurityEvent;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.ui.InputValidator;
+import org.apache.wiki.util.ClassUtil;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
 
-import com.ecyrd.jspwiki.NoRequiredPropertyException;
-import com.ecyrd.jspwiki.WikiContext;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
-import com.ecyrd.jspwiki.auth.*;
-import com.ecyrd.jspwiki.auth.user.UserProfile;
-import com.ecyrd.jspwiki.event.WikiEvent;
-import com.ecyrd.jspwiki.event.WikiEventListener;
-import com.ecyrd.jspwiki.event.WikiEventManager;
-import com.ecyrd.jspwiki.event.WikiSecurityEvent;
-import com.ecyrd.jspwiki.ui.InputValidator;
-import com.ecyrd.jspwiki.util.ClassUtil;
 
 /**
  * <p>
@@ -127,7 +127,7 @@
      * @throws WikiSecurityException if the group name isn't allowed
      * @throws NoSuchPrincipalException if the group isn't found, and
      *             <code>create</code> is <code>false</code>
-     * @see com.ecyrd.jspwiki.auth.authorize.Group#RESTRICTED_GROUPNAMES
+     * @see org.apache.wiki.auth.authorize.Group#RESTRICTED_GROUPNAMES
      */
     public Group getGroup( String name, boolean create ) throws NoSuchPrincipalException, WikiSecurityException
     {
@@ -177,9 +177,9 @@
      * Returns the current external {@link GroupDatabase} in use. This method
      * is guaranteed to return a properly-initialized GroupDatabase, unless
      * it could not be initialized. In that case, this method throws
-     * a {@link org.apache.jspwiki.api.WikiException}. The GroupDatabase
+     * a {@link org.apache.wiki.api.WikiException}. The GroupDatabase
      * is lazily initialized.
-     * @throws com.ecyrd.jspwiki.auth.WikiSecurityException if the GroupDatabase could
+     * @throws org.apache.wiki.auth.WikiSecurityException if the GroupDatabase could
      * not be initialized
      * @return the current GroupDatabase
      * @since 2.3
@@ -203,7 +203,7 @@
                 dbClassName = XMLGroupDatabase.class.getName();
             }
             log.info( "Attempting to load group database class " + dbClassName );
-            Class<?> dbClass = ClassUtil.findClass( "com.ecyrd.jspwiki.auth.authorize", dbClassName );
+            Class<?> dbClass = ClassUtil.findClass( "org.apache.wiki.auth.authorize", dbClassName );
             m_groupDatabase = (GroupDatabase) dbClass.newInstance();
             m_groupDatabase.initialize( m_engine, m_engine.getWikiProperties() );
             log.info( "Group database initialized." );
@@ -258,7 +258,7 @@
      * obtaining a list of all of the groups it stores.
      * @param engine the wiki engine
      * @param props the properties used to initialize the wiki engine
-     * @see GroupDatabase#initialize(com.ecyrd.jspwiki.WikiEngine,
+     * @see GroupDatabase#initialize(org.apache.wiki.WikiEngine,
      *      java.util.Properties)
      * @see GroupDatabase#groups()
      * @throws WikiSecurityException if GroupManager cannot be initialized
@@ -369,7 +369,7 @@
      *            groups that do not exist will cause a
      *            <code>NoSuchPrincipalException</code> to be thrown
      * @return a new, populated group
-     * @see com.ecyrd.jspwiki.auth.authorize.Group#RESTRICTED_GROUPNAMES
+     * @see org.apache.wiki.auth.authorize.Group#RESTRICTED_GROUPNAMES
      * @throws WikiSecurityException if the group name isn't allowed, or if
      * <code>create</code> is <code>false</code>
      * and the Group named <code>name</code> does not exist
@@ -493,14 +493,14 @@
      * Removes a named Group from the group database. If not found, throws a
      * <code>NoSuchPrincipalException</code>. After removal, this method will
      * commit the delete to the back-end group database. It will also fire a
-     * {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#GROUP_REMOVE} event with
+     * {@link org.apache.wiki.event.WikiSecurityEvent#GROUP_REMOVE} event with
      * the GroupManager instance as the source and the Group as target.
      * If <code>index</code> is <code>null</code>, this method throws
      * an {@link IllegalArgumentException}.
      * @param index the group to remove
      * @throws WikiSecurityException if the Group cannot be removed by
      * the back-end
-     * @see com.ecyrd.jspwiki.auth.authorize.GroupDatabase#delete(Group)
+     * @see org.apache.wiki.auth.authorize.GroupDatabase#delete(Group)
      */
     public final void removeGroup( String index ) throws WikiSecurityException
     {
@@ -538,13 +538,13 @@
      * </p>
      * <ul>
      * <li><strong>When creating a new Group</strong>, this method fires a
-     * {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#GROUP_ADD} with the
+     * {@link org.apache.wiki.event.WikiSecurityEvent#GROUP_ADD} with the
      * GroupManager instance as its source and the new Group as the target.</li>
      * <li><strong>When overwriting an existing Group</strong>, this method
-     * fires a new {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#GROUP_REMOVE}
+     * fires a new {@link org.apache.wiki.event.WikiSecurityEvent#GROUP_REMOVE}
      * with this GroupManager instance as the source, and the new Group as the
      * target. It then fires a
-     * {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#GROUP_ADD} event with the
+     * {@link org.apache.wiki.event.WikiSecurityEvent#GROUP_ADD} event with the
      * same source and target.</li>
      * </ul>
      * <p>
@@ -556,7 +556,7 @@
      * </p>
      * <p>
      * This method will register the new Group with the GroupManager. For example,
-     * {@link com.ecyrd.jspwiki.auth.AuthenticationManager} attaches each
+     * {@link org.apache.wiki.auth.AuthenticationManager} attaches each
      * WikiSession as a GroupManager listener. Thus, the act of registering a
      * Group with <code>setGroup</code> means that all WikiSessions will
      * automatically receive group add/change/delete events immediately.
@@ -726,7 +726,7 @@
      *  Fires a WikiSecurityEvent of the provided type, Principal and target Object
      *  to all registered listeners.
      *
-     * @see com.ecyrd.jspwiki.event.WikiSecurityEvent
+     * @see org.apache.wiki.event.WikiSecurityEvent
      * @param type       the event type to be fired
      * @param target     the changed Object, which may be <code>null</code>
      */
@@ -739,7 +739,7 @@
     }
 
     /**
-     * Listens for {@link com.ecyrd.jspwiki.event.WikiSecurityEvent#PROFILE_NAME_CHANGED}
+     * Listens for {@link org.apache.wiki.event.WikiSecurityEvent#PROFILE_NAME_CHANGED}
      * events. If a user profile's name changes, each group is inspected. If an entry contains
      * a name that has changed, it is replaced with the new one. No group events are emitted
      * as a consequence of this method, because the group memberships are still the same; it is

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/JDBCGroupDatabase.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/JDBCGroupDatabase.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/JDBCGroupDatabase.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/JDBCGroupDatabase.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.security.Principal;
 import java.sql.*;
@@ -30,14 +30,15 @@
 import javax.naming.NamingException;
 import javax.sql.DataSource;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.NoRequiredPropertyException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.auth.NoSuchPrincipalException;
+import org.apache.wiki.auth.WikiPrincipal;
+import org.apache.wiki.auth.WikiSecurityException;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+
 
-import com.ecyrd.jspwiki.NoRequiredPropertyException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.auth.NoSuchPrincipalException;
-import com.ecyrd.jspwiki.auth.WikiPrincipal;
-import com.ecyrd.jspwiki.auth.WikiSecurityException;
 
 /**
  * <p>

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Role.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Role.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/XMLGroupDatabase.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/XMLGroupDatabase.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.io.BufferedWriter;
 import java.io.File;
@@ -40,18 +40,18 @@
 import javax.xml.parsers.ParserConfigurationException;
 
 import org.apache.commons.lang.StringEscapeUtils;
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.NoRequiredPropertyException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.auth.NoSuchPrincipalException;
+import org.apache.wiki.auth.WikiPrincipal;
+import org.apache.wiki.auth.WikiSecurityException;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 import org.xml.sax.SAXException;
 
-import com.ecyrd.jspwiki.NoRequiredPropertyException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.auth.NoSuchPrincipalException;
-import com.ecyrd.jspwiki.auth.WikiPrincipal;
-import com.ecyrd.jspwiki.auth.WikiSecurityException;
 
 /**
  * <p>

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AbstractLoginModule.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AbstractLoginModule.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AnonymousLoginModule.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AnonymousLoginModule.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.auth.login;
+package org.apache.wiki.auth.login;
 
 import java.io.IOException;
 
@@ -28,10 +28,11 @@
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.auth.WikiPrincipal;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+
 
-import com.ecyrd.jspwiki.auth.WikiPrincipal;
 
 /**
  * <p>

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AuthorizerCallback.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AuthorizerCallback.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AuthorizerCallback.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AuthorizerCallback.java Sun Feb  1 18:04:05 2009
@@ -18,11 +18,12 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.login;
+package org.apache.wiki.auth.login;
 
 import javax.security.auth.callback.Callback;
 
-import com.ecyrd.jspwiki.auth.Authorizer;
+import org.apache.wiki.auth.Authorizer;
+
 
 /**
  * Callback for requesting and supplying an Authorizer required by a

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/CookieAssertionLoginModule.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/CookieAssertionLoginModule.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/CookieAssertionLoginModule.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/CookieAssertionLoginModule.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.auth.login;
+package org.apache.wiki.auth.login;
 
 import java.io.IOException;
 
@@ -31,12 +31,13 @@
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.auth.WikiPrincipal;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+import org.apache.wiki.util.HttpUtil;
+import org.apache.wiki.util.TextUtil;
+
 
-import com.ecyrd.jspwiki.auth.WikiPrincipal;
-import com.ecyrd.jspwiki.util.HttpUtil;
-import com.ecyrd.jspwiki.util.TextUtil;
 
 /**
  * <p>
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/api/WikiSession.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/api/WikiSession.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.   
  */
-package org.apache.jspwiki.api;
+package org.apache.wiki.api;
 
 import java.security.Principal;
 import java.util.Locale;
@@ -42,14 +42,14 @@
  * <p>To keep track of the Principals each user posseses, each WikiSession
  * stores a JAAS Subject. Various login processes add or remove Principals
  * when users authenticate or log out.</p>
- * <p>WikiSession implements the {@link com.ecyrd.jspwiki.event.WikiEventListener}
+ * <p>WikiSession implements the {@link org.apache.wiki.event.WikiEventListener}
  * interface and listens for group add/change/delete events fired by
  * event sources the WikiSession is registered with. Normally,
- * {@link com.ecyrd.jspwiki.auth.AuthenticationManager} registers each WikiSession
- * with the {@link com.ecyrd.jspwiki.auth.authorize.GroupManager}
+ * {@link org.apache.wiki.auth.AuthenticationManager} registers each WikiSession
+ * with the {@link org.apache.wiki.auth.authorize.GroupManager}
  * so it can catch group events. Thus, when a user is added to a
  * {@link com.ecyrd.jspwiki.auth.authorize.Group}, a corresponding
  * {@link com.ecyrd.jspwiki.auth.GroupPrincipal} is injected into
  * the Subject's Principal set. Likewise, when the user is removed from
  * the Group or the Group is deleted, the GroupPrincipal is removed
  * from the Subject. The effect that this strategy produces is extremely
@@ -62,7 +62,7 @@
  * managing WikiSessions for an entire wiki. These methods allow callers
  * to find, query and remove WikiSession objects, and
  * to obtain a list of the current wiki session users.</p>
- * <p>WikiSession encloses a protected static class, {@link com.ecyrd.jspwiki.auth.SessionMonitor},
+ * <p>WikiSession encloses a protected static class, {@link org.apache.wiki.auth.SessionMonitor},
  * to keep track of WikiSessions registered with each wiki.</p>
  * @author Andrew R. Jaquith
  */
@@ -102,9 +102,9 @@
      * true if any of these conditions are true:</p>
      * <ul>
      *   <li>The session's Principal set contains
-     *       {@link com.ecyrd.jspwiki.auth.authorize.Role#ANONYMOUS}</li>
+     *       {@link org.apache.wiki.auth.authorize.Role#ANONYMOUS}</li>
      *   <li>The session's Principal set contains
-     *       {@link com.ecyrd.jspwiki.auth.WikiPrincipal#GUEST}</li>
+     *       {@link org.apache.wiki.auth.WikiPrincipal#GUEST}</li>
      *   <li>The Principal returned by {@link #getUserPrincipal()} evaluates
      *       to an IP address.</li>
      * </ul>
@@ -122,7 +122,7 @@
      * <code>LOGIN_NAME</code>; the first one found is the login principal.
      * If one is not found, this method returns the first principal that isn't
      * of type Role or GroupPrincipal. If neither of these conditions hold, this method returns
-     * {@link com.ecyrd.jspwiki.auth.WikiPrincipal#GUEST}.
+     * {@link org.apache.wiki.auth.WikiPrincipal#GUEST}.
      * @return the login Principal. If it is a PrincipalWrapper containing an
      * externally-provided Principal, the object returned is the Principal, not
      * the wrapper around it.
@@ -139,7 +139,7 @@
      *       collection that isn't of type Role or GroupPrincipal is the primary.</li>
      * </ol>
      * If no primary user Principal is found, this method returns
-     * {@link com.ecyrd.jspwiki.auth.WikiPrincipal#GUEST}.
+     * {@link org.apache.wiki.auth.WikiPrincipal#GUEST}.
      * @return the primary user Principal
      */
     public Principal getUserPrincipal();
@@ -208,7 +208,7 @@
      * are those in the Subject's principal collection that aren't of type Role or
      * of type GroupPrincipal. This is a defensive copy.
      * @return Returns the user principal
-     * @see com.ecyrd.jspwiki.auth.AuthenticationManager#isUserPrincipal(Principal)
+     * @see org.apache.wiki.auth.AuthenticationManager#isUserPrincipal(Principal)
      */
     public Principal[] getPrincipals();
 
@@ -239,9 +239,9 @@
     /**
      * <p>Returns the status of the wiki session as a text string. Valid values are:</p>
      * <ul>
-     *   <li>{@link com.ecyrd.jspwiki.WikiSession#AUTHENTICATED}</li>
-     *   <li>{@link com.ecyrd.jspwiki.WikiSession#ASSERTED}</li>
-     *   <li>{@link com.ecyrd.jspwiki.WikiSession#ANONYMOUS}</li>
+     *   <li>{@link org.apache.wiki.WikiSession#AUTHENTICATED}</li>
+     *   <li>{@link org.apache.wiki.WikiSession#ASSERTED}</li>
+     *   <li>{@link org.apache.wiki.WikiSession#ANONYMOUS}</li>
      * </ul>
      * @return the user's session status
      */
@@ -42,14 +42,14 @@
  * so it can catch group events. Thus, when a user is added to a
- * {@link com.ecyrd.jspwiki.auth.authorize.Group}, a corresponding
- * {@link com.ecyrd.jspwiki.auth.GroupPrincipal} is injected into
+ * {@link org.apache.wiki.auth.authorize.Group}, a corresponding
+ * {@link org.apache.wiki.auth.GroupPrincipal} is injected into
  * the Subject's Principal set. Likewise, when the user is removed from
  * the Group or the Group is deleted, the GroupPrincipal is removed

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/Attachment.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/attachment/Attachment.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntry.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntry.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.security.Permission;
 import java.security.Principal;
@@ -49,7 +49,7 @@
     /**
      * Adds the specified permission to this ACL entry. The permission
      * <em>must</em> be of type
      * {@link com.ecyrd.jspwiki.auth.permissions.PagePermission}. Note: An entry
      * can have multiple permissions.
      * @param permission the permission to be associated with the principal in
      *            this entry
@@ -49,7 +49,7 @@
      * Adds the specified permission to this ACL entry. The permission
      * <em>must</em> be of type
-     * {@link com.ecyrd.jspwiki.auth.permissions.PagePermission}. Note: An entry
+     * {@link org.apache.wiki.auth.permissions.PagePermission}. Note: An entry
      * can have multiple permissions.
      * @param permission the permission to be associated with the principal in

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntryImpl.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntryImpl.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntryImpl.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclEntryImpl.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.acl;
+package org.apache.wiki.auth.acl;
 
 import java.io.Serializable;
 import java.security.Permission;
@@ -26,7 +26,8 @@
 import java.util.Enumeration;
 import java.util.Vector;
 
-import com.ecyrd.jspwiki.auth.permissions.PagePermission;
+import org.apache.wiki.auth.permissions.PagePermission;
+
 
 /**
  * Implementation of a JSPWiki AclEntry.
@@ -50,7 +51,7 @@
     /**
      * Adds the specified permission to this ACL entry. The permission
      * <em>must</em> be of type
      * {@link com.ecyrd.jspwiki.auth.permissions.PagePermission}. Note: An entry
      * can have multiple permissions.
      * @param permission the permission to be associated with the principal in
      *            this entry
@@ -50,7 +51,7 @@
      * Adds the specified permission to this ACL entry. The permission
      * <em>must</em> be of type
-     * {@link com.ecyrd.jspwiki.auth.permissions.PagePermission}. Note: An entry
+     * {@link org.apache.wiki.auth.permissions.PagePermission}. Note: An entry
      * can have multiple permissions.
      * @param permission the permission to be associated with the principal in

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclImpl.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/acl/AclImpl.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Role.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/Role.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.io.Serializable;
 import java.security.Principal;
@@ -26,7 +26,7 @@
 /**
  * A lightweight, immutable Principal that represents a built-in wiki role such
  * as Anonymous, Asserted and Authenticated. It can also represent dynamic roles
  * used by an external {@link com.ecyrd.jspwiki.auth.Authorizer}, such as a web
  * container.
  * @author Andrew Jaquith
  * @since 2.3
@@ -26,7 +26,7 @@
  * A lightweight, immutable Principal that represents a built-in wiki role such
  * as Anonymous, Asserted and Authenticated. It can also represent dynamic roles
- * used by an external {@link com.ecyrd.jspwiki.auth.Authorizer}, such as a web
+ * used by an external {@link org.apache.wiki.auth.Authorizer}, such as a web
  * container.
  * @author Andrew Jaquith

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebAuthorizer.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebAuthorizer.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebAuthorizer.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebAuthorizer.java Sun Feb  1 18:04:05 2009
@@ -18,16 +18,17 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.security.Principal;
 
 import javax.servlet.http.HttpServletRequest;
 
-import com.ecyrd.jspwiki.auth.Authorizer;
+import org.apache.wiki.auth.Authorizer;
+
 
 /**
  * Extends the {@link com.ecyrd.jspwiki.auth.Authorizer} interface by
  * including a delgate method for 
  * {@link javax.servlet.http.HttpServletRequest#isUserInRole(String)}.
  * @author Andrew Jaquith
@@ -18,16 +18,17 @@
 
 /**
- * Extends the {@link com.ecyrd.jspwiki.auth.Authorizer} interface by
+ * Extends the {@link org.apache.wiki.auth.Authorizer} interface by
  * including a delgate method for 
  * {@link javax.servlet.http.HttpServletRequest#isUserInRole(String)}.

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebContainerAuthorizer.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebContainerAuthorizer.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebContainerAuthorizer.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/WebContainerAuthorizer.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.  
  */
-package com.ecyrd.jspwiki.auth.authorize;
+package org.apache.wiki.auth.authorize;
 
 import java.io.IOException;
 import java.net.URL;
@@ -31,8 +31,11 @@
 
 import javax.servlet.http.HttpServletRequest;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.InternalWikiException;
+import org.apache.wiki.WikiEngine;
+import org.apache.wiki.WikiSession;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
 import org.jdom.Document;
 import org.jdom.Element;
 import org.jdom.Namespace;
@@ -43,9 +46,6 @@
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 
-import com.ecyrd.jspwiki.InternalWikiException;
-import com.ecyrd.jspwiki.WikiEngine;
-import com.ecyrd.jspwiki.WikiSession;
 
 /**
  * Authorizes users by delegating role membership checks to the servlet
@@ -168,10 +168,10 @@
      * return <code>false</code>.
      * This method simply examines the WikiSession subject to see if it
      * possesses the desired Principal. We assume that the method
-     * {@link com.ecyrd.jspwiki.ui.WikiServletFilter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)}
+     * {@link org.apache.wiki.ui.WikiServletFilter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)}
      * previously executed, and that it has set the WikiSession
      * subject correctly by logging in the user with the various login modules,
      * in particular {@link com.ecyrd.jspwiki.auth.login.WebContainerLoginModule}}.
      * This is definitely a hack,
      * but it eliminates the need for WikiSession to keep dangling
      * references to the last WikiContext hanging around, just
@@ -181,7 +181,7 @@
      * @param role the role to check
      * @return <code>true</code> if the user is considered to be in the role,
      *         <code>false</code> otherwise
-     * @see com.ecyrd.jspwiki.auth.Authorizer#isUserInRole(com.ecyrd.jspwiki.WikiSession, java.security.Principal)
+     * @see org.apache.wiki.auth.Authorizer#isUserInRole(org.apache.wiki.WikiSession, java.security.Principal)
      */
     public boolean isUserInRole( WikiSession session, Principal role )
     {
@@ -198,7 +198,7 @@
      * initialization, this method returns <code>null</code>.
      * @param role the name of the Role to retrieve
      * @return a Role Principal, or <code>null</code>
-     * @see com.ecyrd.jspwiki.auth.Authorizer#initialize(WikiEngine, Properties)
+     * @see org.apache.wiki.auth.Authorizer#initialize(WikiEngine, Properties)
      */
     public Principal findRole( String role )
     {
@@ -292,7 +292,7 @@
      * certain JSPWiki resources by requiring authentication. Specifically, this
      * method parses JSPWiki's web application descriptor (<code>web.xml</code>)
      * and identifies whether the string representation of
      * {@link com.ecyrd.jspwiki.auth.authorize.Role#AUTHENTICATED} is required
      * to access <code>/Delete.jsp</code> and <code>LoginRedirect.jsp</code>.
      * If the administrator has uncommented the large
      * <code>&lt;security-constraint&gt;</code> section of <code>web.xml</code>,
@@ -168,10 +168,10 @@
      * previously executed, and that it has set the WikiSession
      * subject correctly by logging in the user with the various login modules,
-     * in particular {@link com.ecyrd.jspwiki.auth.login.WebContainerLoginModule}}.
+     * in particular {@link org.apache.wiki.auth.login.WebContainerLoginModule}}.
      * This is definitely a hack,
      * but it eliminates the need for WikiSession to keep dangling
@@ -292,7 +292,7 @@
      * method parses JSPWiki's web application descriptor (<code>web.xml</code>)
      * and identifies whether the string representation of
-     * {@link com.ecyrd.jspwiki.auth.authorize.Role#AUTHENTICATED} is required
+     * {@link org.apache.wiki.auth.authorize.Role#AUTHENTICATED} is required
      * to access <code>/Delete.jsp</code> and <code>LoginRedirect.jsp</code>.
      * If the administrator has uncommented the large

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/XMLGroupDatabase.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/authorize/XMLGroupDatabase.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================
--- incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AbstractLoginModule.java (original)
+++ incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AbstractLoginModule.java Sun Feb  1 18:04:05 2009
@@ -18,7 +18,7 @@
     specific language governing permissions and limitations
     under the License.    
  */
-package com.ecyrd.jspwiki.auth.login;
+package org.apache.wiki.auth.login;
 
 import java.security.Principal;
 import java.util.Collection;
@@ -30,10 +30,11 @@
 import javax.security.auth.login.LoginException;
 import javax.security.auth.spi.LoginModule;
 
-import com.ecyrd.jspwiki.log.Logger;
-import com.ecyrd.jspwiki.log.LoggerFactory;
+import org.apache.wiki.auth.WikiPrincipal;
+import org.apache.wiki.log.Logger;
+import org.apache.wiki.log.LoggerFactory;
+
 
-import com.ecyrd.jspwiki.auth.WikiPrincipal;
 
 /**
  * Abstract JAAS {@link javax.security.auth.spi.LoginModule}that implements
@@ -77,7 +78,7 @@
      * to specify what Principals <em>must</em> be removed if login for
      * this module, or for the entire login configuration overall, fails.
      * Generally, these will be Principals of type
-     * {@link com.ecyrd.jspwiki.auth.authorize.Role}.
+     * {@link org.apache.wiki.auth.authorize.Role}.
      * @deprecated
      */
     protected Collection<Principal>      m_principalsToRemove;
@@ -87,12 +88,12 @@
      * what Principals, perhaps suppled by other LoginModules, <em>must</em>
      * be removed if login for this module, or for the entire login
      * configuration overall, succeeds. Generally, these will be Principals of
      * type {@link com.ecyrd.jspwiki.auth.authorize.Role}. For example,
      * {@link CookieAssertionLoginModule} adds
      * {@link com.ecyrd.jspwiki.auth.authorize.Role#ANONYMOUS} to its
      * <code>m_principalsToOverwrite</code> collection because when it
-     * succeeds, its own {@link com.ecyrd.jspwiki.auth.authorize.Role#AUTHENTICATED}
-     * should over-write {@link com.ecyrd.jspwiki.auth.authorize.Role#ANONYMOUS}.
+     * succeeds, its own {@link org.apache.wiki.auth.authorize.Role#AUTHENTICATED}
+     * should over-write {@link org.apache.wiki.auth.authorize.Role#ANONYMOUS}.
      * @deprecated
      */
     protected Collection<Principal>      m_principalsToOverwrite;
@@ -87,12 +88,12 @@
      * be removed if login for this module, or for the entire login
      * configuration overall, succeeds. Generally, these will be Principals of
-     * type {@link com.ecyrd.jspwiki.auth.authorize.Role}. For example,
+     * type {@link org.apache.wiki.auth.authorize.Role}. For example,
      * {@link CookieAssertionLoginModule} adds
@@ -87,12 +88,12 @@
      * {@link CookieAssertionLoginModule} adds
-     * {@link com.ecyrd.jspwiki.auth.authorize.Role#ANONYMOUS} to its
+     * {@link org.apache.wiki.auth.authorize.Role#ANONYMOUS} to its
      * <code>m_principalsToOverwrite</code> collection because when it

Modified: incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AnonymousLoginModule.java
URL: http://svn.apache.org/viewvc/incubator/jspwiki/trunk/src/java/org/apache/wiki/auth/login/AnonymousLoginModule.java?rev=739802&r1=739575&r2=739802&view=diff
==============================================================================